var NCSDK = window.NCSDK;
var Toast = NCSDK.Toast;
var Alert = NCSDK.Alert;
var Jump = NCSDK.Jump;
var File = NCSDK.File;
var Device = NCSDK.Device;
var System = NCSDK.System;
var Db = NCSDK.Db;
var Net = NCSDK.Net;
var Picker = NCSDK.Picker;
var Refresh = NCSDK.Refresh;
var Clipboard = NCSDK.Clipboard;

var oPage = {
    init: fInit,
    initPicker: fInitPicker,
    initClipboard: fInitClipboard,
    initRefresh: fInitRefresh,
    initNet: fInitNet,
    initDb: fInitDb,
    initSystem: fInitSystem,
    initDevice: fInitDevice,
    initFile: fInitFile,
    initJump: fInitJump,
    initAlert: fInitAlert,
    initToast: fInitToast,
    line: fLine
};
oPage.init();

function fInit() {
    var that = this;
    that.initPicker();
    that.initClipboard();
    that.initRefresh();
    that.initNet();
    that.initDb();
    that.initSystem();
    that.initDevice();
    that.initFile();
    that.initJump();
    that.initAlert();
    that.initToast();
}

function fInitPicker() {
    var that = this;
    that.line('picker', [{
        name: '单列',
        click: function () {
            Picker.single({
                title: '单列',
                items: '0123456789'.split('').map(function (sItem, nIndex) {
                    return {text: sItem, selected: nIndex === 5}
                }),
                call: function (bConfirm, nIndex, oItem) {
                    window.setTimeout(function () {
                        bConfirm && Toast.success({content: oItem.text});
                        !bConfirm && Toast.error({content: '取消'});
                    }, 1000);
                }
            });
        }
    }, {
        name: '多列',
        click: function () {
            Picker.multiple({
                title: '多列',
                items: '0123456789,abcdefghijklmnopqrstuvwxyz,ABCDEFGHIJKLMNOPQRSTUVWXYZ'.split(',').map(function (sItem) {
                    return sItem.split('').map(function (sItem, nIndex) {
                        return {text: sItem, selected: nIndex === 5}
                    });
                }),
                call: function (bConfirm, aIndex, aItem) {
                    window.setTimeout(function () {
                        if (bConfirm) {
                            var sText = aItem.map(function (oItem) {
                                return oItem.text
                            }).join('\n');
                            bConfirm && Toast.success({content: sText});
                        } else {
                            Toast.error({content: '取消'});
                        }
                    }, 1000);
                }
            });
        }
    }, {
        name: '联动',
        click: function () {
            Picker.link({
                title: '联动',
                items: [
                    {text: "中国", value: "china", selected: false},
                    {text: "美国", value: "USA", selected: true},
                    {text: "广东", value: "china1", selected: false, parent: "china"},
                    {text: "广西", value: "china2", selected: false, parent: "china"},
                    {text: "美国1", value: "usa1", selected: false, parent: "USA"},
                    {text: "美国2", value: "usa2", selected: true, parent: "USA"},
                    {text: "广州", value: "gz", selected: false, parent: "china1"},
                    {text: "深圳", value: "sz", selected: false, parent: "china1"},
                    {text: "广西1", value: "gx1", selected: false, parent: "china2"},
                    {text: "广西2", value: "gx2", selected: false, parent: "china2"},
                    {text: "美国11", value: "0003", selected: false, parent: "usa1"},
                    {text: "美国12", value: "0004", selected: false, parent: "usa1"},
                    {text: "美国21", value: "0005", selected: false, parent: "usa2"},
                    {text: "美国22", value: "0006", selected: false, parent: "usa2"},
                    {text: "美国23", value: "0007", selected: true, parent: "usa2"},
                    {text: "美国24", value: "0008", selected: false, parent: "usa2"}],
                call: function (bConfirm, aItem) {
                    window.setTimeout(function () {
                        if (bConfirm) {
                            var sText = aItem.map(function (oItem) {
                                return oItem.text
                            }).join('\n');
                            bConfirm && Toast.success({content: sText});
                        } else {
                            Toast.error({content: '取消'});
                        }
                    }, 1000);
                }
            });
        }
    }, {
        name: 'time',
        click: function () {
            Picker.time({
                title: '时间',
                interval: 3,
                date: {hour: 20, minute: 17},
                call: function (bConfirm, oDate) {
                    window.setTimeout(function () {
                        bConfirm && Toast.success({content: [oDate.hour, oDate.minute].join(':')});
                        !bConfirm && Toast.error({content: '取消'});
                    }, 1000);
                }
            });
        }
    }, {
        name: 'date',
        click: function () {
            Picker.date({
                title: '日期',
                date: {year: 2018, month: 5, day: 1},
                min: {year: 2005, month: 12, day: 14},
                max: {year: 2020, month: 2, day: 20},
                call: function (bConfirm, oDate) {
                    window.setTimeout(function () {
                        bConfirm && Toast.success({content: [oDate.year, oDate.month, oDate.day].join('-')});
                        !bConfirm && Toast.error({content: '取消'});
                    }, 1000);
                }
            });
        }
    }, {
        name: 'dateAndTime',
        click: function () {
            Picker.dateAndTime({
                title: '日期+时间',
                interval: 20,
                date: {month: 5, day: 1, hour: 5, min: 1},
                min: {month: 2, day: 3, hour: 4, min: 5},
                max: {month: 11, day: 12, hour: 13, min: 14},
                call: function (bConfirm, oDate) {
                    window.setTimeout(function () {
                        bConfirm && Toast.success({content: [oDate.month, oDate.day].join('-') + ' ' + [oDate.hour, oDate.minute].join(':')});
                        !bConfirm && Toast.error({content: '取消'});
                    }, 1000);
                }
            });
        }
    }]);
}

function fInitClipboard() {
    var that = this;
    that.line('clipboard', [{
        name: '设置',
        click: function () {
            Clipboard.set({
                text: new Date().getTime(),
                call: function () {
                    Toast.success({content: 'done'});
                }
            });
        }
    }, {
        name: '获取',
        click: function () {
            Clipboard.get({
                call: function (sText) {
                    Alert.alert({content: sText});
                }
            });
        }
    }]);
}

function fInitRefresh() {
    var that = this;
    Refresh.onStart(function () {
        Toast.success({content: 'start'});
    });
    Refresh.onStop(function () {
        Toast.success({content: 'stop'});
    });
    that.line('refresh', [{
        name: '启用',
        click: function () {
            Refresh.set({
                use: true,
                call: function () {
                    // Alert.alert({content: '启用'});
                }
            });
        }
    }, {
        name: '停用',
        click: function () {
            Refresh.set({
                use: false,
                call: function () {
                    // Alert.alert({content: '停用'});
                }
            });
        }
    }, {
        name: '开始',
        click: function () {
            Refresh.start({
                call: function () {
                    // Alert.alert({content: '开始'});
                }
            });
        }
    }, {
        name: '停止',
        click: function () {
            Refresh.stop({
                call: function () {
                    // Alert.alert({content: '停止'});
                }
            });
        }
    }]);
}

function fInitNet() {
    var that = this;
    that.line('net', [{
        name: 'request',
        click: function () {
            Net.request({
                type: 'get',
                url: 'http://m.nowcoder.com/discuss/get-discusses-v2',
                query: {type: 0, order: 3, page: 1},
                call: function (oResult) {
                    Alert.alert({content: JSON.stringify(oResult)});
                }
            });
        }
    }]);
}

function fInitDb() {
    var that = this;
    that.line('db', [{
        name: 'set',
        click: function () {
            Db.set({
                key: 'test',
                value: new Date().getTime(),
                call: function (bSuccess) {
                    bSuccess && Toast.success({content: 'set'});
                    !bSuccess && Toast.error({content: 'set'});
                }
            });
        }
    }, {
        name: 'get',
        click: function () {
            Db.get({
                key: 'test',
                call: function (oData) {
                    Toast.success({content: JSON.stringify(oData)});
                }
            });
        }
    }, {
        name: 'remove',
        click: function () {
            Db.remove({
                key: 'test',
                call: function (bSuccess) {
                    bSuccess && Toast.success({content: 'remove'});
                    !bSuccess && Toast.error({content: 'remove'});
                }
            });
        }
    }]);

    that.line('dbSync', [{
        name: 'setSync',
        click: function () {
            Db.setSync('test', new Date().getTime());
            Toast.success({content: 'set'});
        }
    }, {
        name: 'getSync',
        click: function () {
            var oData = Db.getSync('test');
            Toast.success({content: JSON.stringify(oData)});
        }
    }, {
        name: 'removeSync',
        click: function () {
            Db.removeSync('test');
            Toast.success({content: 'remove'});
        }
    }]);
}

function fInitSystem() {
    var that = this;
    var oDv = that.line('system', [{
        name: 'hideKeyboard',
        click: function (oEl, oItem) {
            System.hideKeyboard();
        }
    }, {
        name: 'appVersion',
        click: function (oEl, oItem) {
            System.appVersion({
                call: function (nVersion) {
                    Alert.alert({content: nVersion});
                }
            });
        }
    }, {
        name: 'battery',
        click: function (oEl, oItem) {
            System.battery({
                call: function (oItem) {
                    Alert.alert({content: JSON.stringify(oItem)});
                }
            });
        }
    }, {
        name: 'disk',
        click: function (oEl, oItem) {
            System.disk({
                call: function (oItem) {
                    Alert.alert({content: JSON.stringify(oItem)});
                }
            });
        }
    }, {
        name: 'memory',
        click: function (oEl, oItem) {
            System.memory({
                call: function (oItem) {
                    Alert.alert({content: JSON.stringify(oItem)});
                }
            });
        }
    }, {
        name: 'volume.get',
        click: function (oEl, oItem) {
            System.volume({
                call: function (nValue) {
                    Alert.alert({content: nValue});
                }
            });
        }
    }, {
        name: 'volume.set',
        click: function (oEl, oItem) {
            Alert.input({
                title: '输入值',
                inputs: [{text: 0.5}],
                call: function (bConfirm, aItem) {
                    bConfirm && System.volume({
                        value: +aItem[0] || 0,
                        call: function () {
                            Toast.success({content: 'volume.set'});
                        }
                    });
                }
            });
        }
    }, {
        name: 'brightness.get',
        click: function (oEl, oItem) {
            System.brightness({
                call: function (nValue) {
                    Alert.alert({content: nValue});
                }
            });
        }
    }, {
        name: 'brightness.set',
        click: function (oEl, oItem) {
            Alert.input({
                title: '输入值',
                inputs: [{text: 0.5}],
                call: function (bConfirm, aItem) {
                    bConfirm && System.brightness({
                        value: +aItem[0] || 0,
                        call: function () {
                            Toast.success({content: 'brightness.set'});
                        }
                    });
                }
            });
        }
    }, {
        name: 'keepScreen.get',
        click: function (oEl, oItem) {
            System.keepScreen({
                call: function (nValue) {
                    Alert.alert({content: nValue});
                }
            });
        }
    }, {
        name: 'keepScreen.set',
        click: function (oEl, oItem) {
            Alert.confirm({
                title: '是否常亮',
                confirmText: '常亮',
                cancelText: '不常亮',
                call: function (bConfirm) {
                    System.keepScreen({
                        value: bConfirm,
                        call: function () {
                            Toast.success({content: 'keepScreen.set'});
                        }
                    });
                }
            });
        }
    }]);

    var oTempDv = document.createElement('div');
    oTempDv.innerHTML = '<input type="text" placeholder="点击出现键盘" />';
    oDv.appendChild(oTempDv);
}

function fInitDevice() {
    var that = this;
    that.line('device', [{
        name: 'info',
        click: function (oEl, oItem) {
            Device.info({
                call: function (oResult) {
                    Alert.alert({content: JSON.stringify(oResult)});
                }
            });
        }
    }]);
}

function fInitFile() {
    var that = this;
    var sPath = '/sdk/test/write.txt';
    var sDir = '/sdk/test';
    that.line('file', [{
        name: 'write',
        click: function (oEl, oItem) {
            File.write({
                path: sPath,
                content: 'Hello world',
                call: function (bSuccess) {
                    bSuccess && Toast.success({content: 'write'});
                    !bSuccess && Toast.error({content: 'write'});
                }
            });
        }
    }, {
        name: 'read',
        click: function (oEl, oItem) {
            File.read({
                path: sPath,
                call: function (sContent) {
                    Alert.alert({content: sContent});
                }
            });
        }
    }, {
        name: 'del',
        click: function (oEl, oItem) {
            File.del({
                path: sPath,
                call: function (bSuccess) {
                    bSuccess && Toast.success({content: 'del'});
                    !bSuccess && Toast.error({content: 'del'});
                }
            });
        }
    }, {
        name: 'ls',
        click: function (oEl, oItem) {
            File.ls({
                path: sDir,
                call: function (aItem) {
                    Alert.alert({content: aItem.join('\n') || '没有文件'});
                }
            })
        }
    }, {
        name: 'exist',
        click: function (oEl, oItem) {
            File.exist({
                path: sPath,
                call: function (bExist) {
                    bExist && Toast.success({content: 'exist'});
                    !bExist && Toast.error({content: 'no exist'});
                }
            })
        }
    }, {
        name: 'isFile',
        click: function (oEl, oItem) {
            File.isFile({
                path: sPath,
                call: function (bFile) {
                    bFile && Toast.success({content: 'file'});
                    !bFile && Toast.error({content: 'no file'});
                }
            });
        }
    }, {
        name: 'isDir',
        click: function (oEl, oItem) {
            File.isDir({
                path: sDir,
                call: function (bDir) {
                    bDir && Toast.success({content: 'dir'});
                    !bDir && Toast.error({content: 'no dir'});
                }
            });
        }
    }, {
        name: 'size',
        click: function (oEl, oItem) {
            File.size({
                path: sPath,
                call: function (nSize) {
                    Alert.alert({content: nSize || 0});
                }
            });
        }
    }, {
        name: 'mkdir',
        click: function (oEl, oItem) {
            File.mkdir({
                path: sDir + '/temp/mkdir.txt',
                isFile: true,
                call: function (bSuccess) {
                    bSuccess && Toast.success({content: 'mkdir'});
                    !bSuccess && Toast.error({content: 'mkdir'});
                }
            });
        }
    }]);
}

function fInitJump() {
    var that = this;
    that.line('alert', [{
        name: 'setting',
        click: function (oEl, oItem) {
            Jump.setting({
                call: function () {
                    Toast.success({content: 'setting'});
                }
            });
        }
    }, {
        name: 'tel',
        click: function (oEl, oItem) {
            Jump.tel({
                to: '13560338217',
                call: function () {
                    Toast.success({content: 'tel'});
                }
            });
        }
    }, {
        name: 'sms',
        click: function (oEl, oItem) {
            Jump.sms({
                to: '13560338217',
                call: function () {
                    Toast.success({content: 'sms'});
                }
            });
        }
    }, {
        name: 'facetime',
        click: function (oEl, oItem) {
            Jump.facetime({
                to: '13560338217',
                call: function () {
                    Toast.success({content: 'facetime'});
                }
            });
        }
    }, {
        name: 'mailto',
        click: function (oEl, oItem) {
            Jump.mailto({
                to: 'huaxinjiayou@gmail.com',
                call: function () {
                    Toast.success({content: 'mailto'});
                }
            });
        }
    }, {
        name: 'open',
        click: function (oEl, oItem) {
            Jump.open({
                to: 'tel://13560338217',
                call: function () {
                    Toast.success({content: 'open'});
                }
            });
        }
    }]);
}

function fInitAlert() {
    var that = this;
    that.line('alert', [{
        name: 'alert',
        click: function (oEl, oItem) {
            Alert.alert({
                title: 'title',
                content: 'content',
                confirmText: 'confirm',
                call: function () {
                    Toast.success({content: 'confirm'});
                },
                complete: function () {
                    Toast.success({content: '系统已执行'});
                }
            });
        }
    }, {
        name: 'confirm',
        click: function (oEl, oItem) {
            Alert.confirm({
                title: 'title',
                content: 'content',
                confirmText: 'confirm',
                cancelText: 'cancel',
                call: function (bConfirm) {
                    bConfirm && Toast.success({content: 'confirm'});
                    !bConfirm && Toast.error({content: 'cancel'});
                }
            });
        }
    }, {
        name: 'input',
        click: function (oEl, oItem) {
            Alert.input({
                title: 'title',
                content: 'content',
                confirmText: 'confirm',
                cancelText: 'cancel',
                inputs: [{text: '1', placeholder: '1.1'}, {text: '2', placeholder: '2.2'}],
                call: function (bConfirm, aItem) {
                    bConfirm && Toast.success({content: aItem.join('\n')});
                    !bConfirm && Toast.error({content: 'cancel'});
                }
            });
        }
    }, {
        name: 'sheet system',
        click: function (oEl, oItem) {
            Alert.sheet({
                title: 'title',
                content: 'content',
                cancelText: 'cancel',
                buttons: [{title: '1', checked: true}, {title: '2'}, {title: '3'}],
                system: true,
                call: function (bConfirm, nIndex, aItem) {
                    bConfirm && Toast.success({content: aItem[nIndex].title});
                    !bConfirm && Toast.error({content: 'cancel'});
                }
            });
        }
    }, {
        name: 'sheet custom',
        click: function (oEl, oItem) {
            Alert.sheet({
                content: 'content',
                cancelText: 'cancel',
                // color: '#333333',
                // colorChecked: '#00bc9b',
                buttons: [{title: '1', checked: true}, {title: '2'}, {title: '3'}],
                system: false,
                call: function (bConfirm, nIndex, aItem) {
                    bConfirm && Toast.success({content: aItem[nIndex].title});
                    !bConfirm && Toast.error({content: 'cancel'});
                }
            });
        }
    }]);
}

function fInitToast() {
    var that = this;
    var oTimer = null;
    that.line('toast', [{
        name: 'success',
        click: function (oEl, oItem) {
            Toast.success({
                content: 'success',
                mask: false
            });
        }
    }, {
        name: 'error',
        click: function (oEl, oItem) {
            Toast.error({
                content: 'error',
                mask: false
            });
        }
    }, {
        name: 'info',
        click: function (oEl, oItem) {
            Toast.info({
                content: 'info',
                mask: false
            });
        }
    }, {
        name: 'wait',
        click: function (oEl, oItem) {
            clearTimeout(oTimer);
            Toast.wait({
                content: 'wait',
                mask: false
            });
            oTimer = setTimeout(function () {
                Toast.hide();
            }, 2000);
        }
    }, {
        name: 'progress',
        click: function (oEl, oItem) {
            var nStep = 0.02;
            _fProgress(nStep);

            function _fProgress(nProgress) {
                clearTimeout(oTimer);
                Toast.progress({
                    progress: nProgress,
                    content: 'progress',
                    complete: function () {
                        oTimer = setTimeout(function () {
                            nProgress >= 1 && Toast.hide();
                            nProgress < 1 && _fProgress(nProgress + nStep);
                        }, 50);
                    }
                })
            }
        }
    }, {
        name: 'hide',
        click: function (oEl, oItem) {
            clearTimeout(oTimer);
            Toast.hide();
        }
    }]);
}

function fLine(sName, aItem) {
    var oEl = document.getElementById('jsAction');
    var oDv = document.createElement('div');
    oDv.innerHTML = '<div>' + sName + '</div>';
    aItem.forEach(function (oItem) {
        var oA = document.createElement('a');
        oA.style.marginRight = '10px';
        oA.innerHTML = oItem.name;
        oA.setAttribute('href', 'javascript:void(0);');
        oA.addEventListener('click', function (oEvent) {
            oItem.click && oItem.click(oA, oItem)
        });
        oDv.appendChild(oA);
    });
    oEl.appendChild(oDv);
    return oDv;
}